.. _paster_module:

:mod:`pyramid.paster`
---------------------------

.. automodule:: pyramid.paster

    .. autofunction:: bootstrap

    .. autofunction:: get_app(config_uri, name=None, options=None)

    .. autofunction:: get_appsettings(config_uri, name=None, options=None)

    .. autofunction:: setup_logging(config_uri)
